@@ -508,7 +508,8 @@ class Variable(VariableInterface):
                                 "{vartype}")
                     self.raiseWrongChoice(name, tipChoice, val, error)
                 if "choice" in self.type and not "choiceedit" in self.type:
-                    if (choiceVal and val and val not in choiceVal or
+                    if (choiceVal and (val or val == "") and
+                                val not in choiceVal or
                                 val is None):
                         if not choiceVal:
                             self.raiseNothingValue()
