@@ -36,8 +36,9 @@ class Locale(object):
             'name': 'Беларуская (Беларусь)',
             'locale': 'be_BY.UTF-8',
             'keymap': 'by',
+            'timezone': 'Europe/Minsk',
             'dumpkeys_charset': 'koi8-u',
-            'consolefont': 'Cyr_a8x16',
+            'consolefont': 'ter-v14n',
             'xkblayout': 'us,by',
             'language': 'be',
         },
@@ -46,71 +47,179 @@ class Locale(object):
             'locale': 'bg_BG.UTF-8',
             'keymap': 'bg_bds-utf8',
             'dumpkeys_charset': '',
-            'consolefont': 'ter-m14n',
+            'timezone': 'Europe/Sofia',
+            'consolefont': 'ter-v14n',
             'xkblayout': 'us,bg',
             'language': 'bg',
         },
-        'fr_BE': {
-            'name': 'Français (Belgique)',
-            'locale': 'fr_BE.UTF-8',
-            'keymap': 'be-latin1',
+        'bs_BA': {
+            'name': 'Bosanski (Bosna i Hercegovina)',
+            'locale': 'bs_BA.UTF-8',
+            'keymap': 'slovene',
+            'timezone': 'Europe/Sarajevo',
             'dumpkeys_charset': '',
-            'consolefont': 'lat9w-16',
-            'xkblayout': 'us,be',
-            'language': 'fr',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'ba',
+            'language': 'bs',
         },
-        'pt_BR': {
-            'name': 'Português (Brasil)',
-            'locale': 'pt_BR.UTF-8',
-            'keymap': 'br-abnt2',
+        'cs_CZ': {
+            'name': 'Čeština (Česká republika)',
+            'locale': 'cs_CZ.UTF-8',
+            'keymap': 'cz',
+            'timezone': 'Europe/Prague',
             'dumpkeys_charset': '',
-            'consolefont': 'lat9w-16',
-            'xkblayout': 'pt,us',
-            'language': 'pt_BR',
-        },
-        'fr_CA': {
-            'name': 'Français (Canada)',
-            'locale': 'fr_CA.UTF-8',
-            'keymap': 'cf',
-            'dumpkeys_charset': '',
-            'consolefont': 'default8x16',
-            'xkblayout': 'us,ca_enhanced',
-            'language': 'fr',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'cz',
+            'language': 'cs',
         },
         'da_DK': {
             'name': 'Dansk (Danmark)',
             'locale': 'da_DK.UTF-8',
             'keymap': 'dk-latin1',
+            'timezone': 'Europe/Copenhagen',
             'dumpkeys_charset': '',
-            'consolefont': 'lat0-16',
-            'xkblayout': 'us,dk',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'dk',
             'language': 'da',
         },
-        'fr_FR': {
-            'name': 'Français (France)',
-            'locale': 'fr_FR.UTF-8',
-            'keymap': 'fr-latin9',
-            'dumpkeys_charset': '',
-            'consolefont': 'lat0-16',
-            'xkblayout': 'fr,us',
-            'language': 'fr',
-        },
         'de_DE': {
             'name': 'Deutsch (Deutschland)',
             'locale': 'de_DE.UTF-8',
             'keymap': 'de-latin1',
+            'timezone': 'Europe/Berlin',
             'dumpkeys_charset': '',
-            'consolefont': 'lat9w-16',
-            'xkblayout': 'de,us',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'de',
             'language': 'de',
         },
+        'en_AU': {
+            'name': 'English (Australia)',
+            'locale': 'en_AU.UTF-8',
+            'keymap': 'us',
+            'timezone': 'Australia/Canberra',
+            'dumpkeys_charset': '',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'us',
+            'language': 'en_AU',
+        },
+        'en_GB': {
+            'name': 'English (United Kingdom)',
+            'locale': 'en_GB.UTF-8',
+            'keymap': 'uk',
+            'timezone': 'Europe/London',
+            'dumpkeys_charset': '',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'gb',
+            'language': 'en_GB',
+        },
+        'en_US': {
+            'name': 'English (United States)',
+            'locale': 'en_US.UTF-8',
+            'keymap': 'us',
+            'timezone': 'America/New_York',
+            'dumpkeys_charset': '',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'us',
+            'language': 'en',
+        },
+        'es_ES': {
+            'name': 'Español (España)',
+            'locale': 'es_ES.UTF-8',
+            'keymap': 'es euro2',
+            'timezone': 'Europe/Madrid',
+            'dumpkeys_charset': '',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'es',
+            'language': 'es',
+        },
+        'es_UY': {
+            'name': 'Español (Uruguay)',
+            'locale': 'es_UY.UTF-8',
+            'keymap': 'es',
+            'timezone': 'America/Montevideo',
+            'dumpkeys_charset': '',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'es',
+            'language': 'es_UY',
+        },
+        'es_VE': {
+            'name': 'Español (Venezuela)',
+            'locale': 'es_VE.UTF-8',
+            'keymap': 'es',
+            'timezone': 'America/Caracas',
+            'dumpkeys_charset': '',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'es',
+            'language': 'es_UY',
+        },
+        'et_EE': {
+            'name': 'Eesti (Eesti)',
+            'locale': 'et_EE.UTF-8',
+            'keymap': 'et',
+            'timezone': 'Europe/Tallinn',
+            'dumpkeys_charset': '',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'ee',
+            'language': 'et',
+        },
+        'fi_FI': {
+            'name': 'Suomi (Suomi)',
+            'locale': 'fi_FI.UTF-8',
+            'keymap': 'fi-latin9',
+            'timezone': 'Europe/Helsinki',
+            'dumpkeys_charset': '',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'fi',
+            'language': 'fi',
+        },
+        'fr_BE': {
+            'name': 'Français (Belgique)',
+            'locale': 'fr_BE.UTF-8',
+            'keymap': 'be-latin1',
+            'timezone': 'Europe/Brussels',
+            'dumpkeys_charset': '',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'be',
+            'language': 'fr',
+        },
+        'fr_CA': {
+            'name': 'Français (Canada)',
+            'locale': 'fr_CA.UTF-8',
+            'keymap': 'cf',
+            'timezone': 'Canada/Pacific',
+            'dumpkeys_charset': '',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'ca',
+            'language': 'fr',
+        },
+        'fr_FR': {
+            'name': 'Français (France)',
+            'locale': 'fr_FR.UTF-8',
+            'keymap': 'fr-latin9',
+            'timezone': 'Europe/Paris',
+            'dumpkeys_charset': '',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'fr',
+            'language': 'fr',
+        },
+        'hu_HU': {
+            'name': 'Magyar (Magyarország)',
+            'locale': 'hu_HU.UTF-8',
+            'keymap': 'hu',
+            'timezone': 'Europe/Budapest',
+            'dumpkeys_charset': '',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'hu',
+            'language': 'hu',
+        },
         'is_IS': {
             'name': 'Íslenska (Ísland)',
             'locale': 'is_IS.UTF-8',
             'keymap': 'is-latin1',
+            'timezone': 'Atlantic/Reykjavik',
             'dumpkeys_charset': '',
-            'consolefont': 'cp850-8x16',
-            'xkblayout': 'us,is',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'is',
             'language': 'is',
         },
         'it_IT': {
@@ -118,86 +227,166 @@ class Locale(object):
             'locale': 'it_IT.UTF-8',
             'keymap': 'it',
             'dumpkeys_charset': '',
-            'consolefont': 'default8x16',
-            'xkblayout': 'us,it',
+            'timezone': 'Europe/Rome',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'it',
             'language': 'it',
         },
-        'nl_NL': {
-            'name': 'Nederlands (Nederland)',
-            'locale': 'nl_NL.UTF-8',
-            'keymap': 'nl',
+        'kk_KZ': {
+            'name': 'Қазақ тілі (Қазақстан)',
+            'locale': 'kk_KZ.UTF-8',
+            'keymap': 'kaz_gost-unicode',
+            'timezone': 'Asia/Almaty',
             'dumpkeys_charset': '',
-            'consolefont': 'lat9w-16',
-            'xkblayout': 'us,nl',
-            'language': 'nl_NL',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'us,kz',
+            'language': 'kk',
+        },
+        'lt_LT': {
+            'name': 'Lietuvių (Lietuva)',
+            'locale': 'lt_LT.UTF-8',
+            'keymap': 'lt.baltic',
+            'timezone': 'Europe/Vilnius',
+            'dumpkeys_charset': '',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'lt',
+            'language': 'lt',
+        },
+        'lv_LV': {
+            'name': 'Latviešu (Latvija)',
+            'locale': 'lv_LV.UTF-8',
+            'keymap': 'lv',
+            'timezone': 'Europe/Riga',
+            'dumpkeys_charset': '',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'lv',
+            'language': 'lv',
         },
         'nl_BE': {
             'name': 'Nederlands (België)',
             'locale': 'nl_BE.UTF-8',
             'keymap': 'nl',
+            'timezone': 'Europe/Brussels',
             'dumpkeys_charset': '',
             'consolefont': 'lat9w-16',
-            'xkblayout': 'us,nl',
+            'xkblayout': 'nl',
             'language': 'nl_BE',
         },
+        'nl_NL': {
+            'name': 'Nederlands (Nederland)',
+            'locale': 'nl_NL.UTF-8',
+            'keymap': 'nl',
+            'timezone': 'Europe/Amsterdam',
+            'dumpkeys_charset': '',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'nl',
+            'language': 'nl_NL',
+        },
         'nn_NO': {
             'name': 'Nynorsk (Noreg)',
             'locale': 'nn_NO.UTF-8',
             'keymap': 'no-latin1',
+            'timezone': 'Europe/Oslo',
             'dumpkeys_charset': '',
-            'consolefont': 'lat9w-16',
-            'xkblayout': 'us,no',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'no',
             'language': 'nn',
         },
         'pl_PL': {
             'name': 'Polski (Polska)',
             'locale': 'pl_PL.UTF-8',
             'keymap': 'pl',
+            'timezone': 'Europe/Warsaw',
             'dumpkeys_charset': '',
-            'consolefont': 'lat2-16',
-            'xkblayout': 'us,pl',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'pl',
             'language': 'pl',
         },
+        'pt_BR': {
+            'name': 'Português (Brasil)',
+            'locale': 'pt_BR.UTF-8',
+            'keymap': 'br-abnt2',
+            'timezone': 'Brazil/East',
+            'dumpkeys_charset': '',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'br',
+            'language': 'pt_BR',
+        },
         'pt_PT': {
             'name': 'Português (Portugal)',
             'locale': 'pl_PL.UTF-8@euro',
             'keymap': 'pt-latin9',
             'dumpkeys_charset': '',
-            'consolefont': 'lat0-16',
-            'xkblayout': 'pt,us',
+            'timezone': 'Europe/Lisbon',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'pt',
             'language': 'pt',
         },
         'ro_RO': {
             'name': 'Română (România)',
             'locale': 'ro_RO.UTF-8',
             'keymap': 'ro_win',
+            'timezone': 'Europe/Bucharest',
             'dumpkeys_charset': '',
-            'consolefont': 'lat2-16',
-            'xkblayout': 'ro,us',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'ro',
             'language': 'ro',
         },
         'ru_RU': {
             'name': 'Русский (Россия)',
             'locale': 'ru_RU.UTF-8',
             'keymap': '-u ruwin_cplk-UTF-8',
+            'timezone': 'Europe/Moscow',
             'dumpkeys_charset': '',
-            'consolefont': 'ter-k14n',
-            'xkblayout': 'us,ru(winkeys)',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'us,ru',
             'language': 'ru',
         },
-        'es_ES': {
-            'name': 'Español (España)',
-            'locale': 'es_ES.UTF-8',
-            'keymap': 'es euro2',
+        'sk_SK': {
+            'name': 'Slovenčina (Slovenská republika)',
+            'locale': 'sk_SK.UTF-8',
+            'keymap': 'sk-qwertz',
             'dumpkeys_charset': '',
-            'consolefont': 'lat0-16',
-            'xkblayout': 'es,us',
-            'language': 'es',
+            'timezone': 'Europe/Bratislava',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'sk',
+            'language': 'sk',
+        },
+        'sl_SI': {
+            'name': 'Slovenščina (Slovenija)',
+            'locale': 'sl_SI.UTF-8',
+            'keymap': 'slovene',
+            'timezone': 'Europe/Ljubljana',
+            'dumpkeys_charset': '',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'si',
+            'language': 'sl',
+        },
+        'sq_AL': {
+            'name': 'Shqip (Shqipëria)',
+            'locale': 'sq_AL.UTF-8',
+            'keymap': 'al',
+            'timezone': 'Europe/Tirane',
+            'dumpkeys_charset': '',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'al',
+            'language': 'sq',
+        },
+        'sr_RS': {
+            'name': 'Српски (Србија)',
+            'locale': 'sr_RS.UTF-8',
+            'keymap': 'sr-unicode',
+            'timezone': 'Europe/Belgrade',
+            'dumpkeys_charset': '',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'us,rs',
+            'language': 'sr',
         },
         'sv_SE': {
             'name': 'Svenska (Sverige)',
             'locale': 'sv_SE.UTF-8',
             'keymap': 'sv-latin1',
+            'timezone': 'Europe/Stockholm',
             'dumpkeys_charset': '',
             'consolefont': 'lat0-16',
             'xkblayout': 'us,se',
@@ -207,38 +396,12 @@ class Locale(object):
             'name': 'Українська (Україна)',
             'locale': 'uk_UA.UTF-8',
             'keymap': 'ua-utf',
+            'timezone': 'Europe/Kiev',
             'dumpkeys_charset': 'koi8-u',
             'consolefont': 'ter-v14n',
-            'xkblayout': 'us,ua(winkeys)',
+            'xkblayout': 'us,ua',
             'language': 'ua',
         },
-        'en_GB': {
-            'name': 'English (United Kingdom)',
-            'locale': 'en_GB.UTF-8',
-            'keymap': 'uk',
-            'dumpkeys_charset': '',
-            'consolefont': 'LatArCyrHeb-16',
-            'xkblayout': 'gb',
-            'language': 'en',
-        },
-        'en_AU': {
-            'name': 'English (Australia)',
-            'locale': 'en_AU.UTF-8',
-            'keymap': 'us',
-            'dumpkeys_charset': '',
-            'consolefont': 'LatArCyrHeb-16',
-            'xkblayout': 'us',
-            'language': 'en',
-        },
-        'en_US': {
-            'name': 'English (United States)',
-            'locale': 'en_US.UTF-8',
-            'keymap': 'us',
-            'dumpkeys_charset': '',
-            'consolefont': 'LatArCyrHeb-16',
-            'xkblayout': 'us',
-            'language': 'en',
-        }
     }
 
     def getLangs(self):
@@ -361,14 +524,7 @@ class VariableOsLang(ReadonlyVariable, Locale):
     type = "list"
 
     def get(self):
-        return list(sorted(list(set(self.getLangs()) &
-                                {"en_US", "nl_NL", "nl_BE", "de_DE",
-                                 "es_ES", "en_GB", "en_AU", "fr_BE",
-                                 "fr_CA", "is_IS", "sv_SE", "da_DK",
-                                 "nn_NO", "be_BY",
-                                 "fr_FR", "it_IT", "pl_PL", "pt_BR",
-                                 "uk_UA", "bg_BG", "ru_RU", "ro_RO",
-                                 "pt_PT"})))
+        return list(sorted(list(set(self.getLangs()))))
 
     def humanReadable(self):
         return map(lambda x: self.getFieldByLang("name", x),
