@@ -21,7 +21,7 @@ import re
 from calculate.lib.utils.dracut import Dracut
 from calculate.lib.datavars import Variable, ReadonlyVariable
 from calculate.lib.utils.files import (readFile, process, listDirectory,
-                                       isMount, pathJoin)
+                                       isMount, pathJoin, Mounts)
 from calculate.lib.utils.device import getUdevDeviceInfo, loadEfiVars
 from calculate.lib.utils.common import getKernelUid, getValueFromCmdLine
 
@@ -165,12 +165,14 @@ class VariableClIsoscanPath(ReadonlyVariable):
     def get(self):
         return getValueFromCmdLine("iso-scan/filename", 0) or ""
 
+
 class VariableClIsoscanBasePath(ReadonlyVariable):
     """
     Путь куда монтируется устройство isoscan
     """
     value = Dracut.IsoScanPath
 
+
 class VariableClIsoscanFullpath(ReadonlyVariable):
     """
     Путь в системе до образа с которого загружена система
@@ -184,6 +186,24 @@ class VariableClIsoscanFullpath(ReadonlyVariable):
         return ""
 
 
+class VariableOsRootFlashDev(ReadonlyVariable):
+    """
+    Флешка с которой загружена система
+    """
+
+    def get(self):
+        root_type = self.Get('os_root_type_ext')
+        if root_type in RootType.LiveFlash:
+            mounts = Mounts()
+            return mounts.getBy(mounts.NAME, where=mounts.DIR,
+                                eq=Dracut.IsoLive)
+        elif root_type in RootType.IsoScanFlash:
+            mounts = Mounts()
+            return mounts.getBy(mounts.NAME, where=mounts.DIR,
+                                eq=Dracut.IsoScanPath)
+        return ""
+
+
 class VariableOsRootTypeExt(ReadonlyVariable):
     """
     Расширенный тип загруженной системы
